/*******************************************************************************
 * Copyright (c) 2009 Mia-Software.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Gabriel Barbier (Mia-Software)
 *******************************************************************************/
package org.eclipse.gmt.modisco.kdm.browser.extension.code;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.gmt.modisco.infra.browser.uicore.extensions.naming.AbstractNameProvider;
import org.eclipse.gmt.modisco.omg.kdm.code.AbstractCodeElement;
import org.eclipse.gmt.modisco.omg.kdm.code.AbstractCodeRelationship;
import org.eclipse.gmt.modisco.omg.kdm.code.ArrayType;
import org.eclipse.gmt.modisco.omg.kdm.code.BagType;
import org.eclipse.gmt.modisco.omg.kdm.code.BitType;
import org.eclipse.gmt.modisco.omg.kdm.code.BitstringType;
import org.eclipse.gmt.modisco.omg.kdm.code.BooleanType;
import org.eclipse.gmt.modisco.omg.kdm.code.CallableUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.CharType;
import org.eclipse.gmt.modisco.omg.kdm.code.ChoiceType;
import org.eclipse.gmt.modisco.omg.kdm.code.ClassUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.CodeAssembly;
import org.eclipse.gmt.modisco.omg.kdm.code.CodeElement;
import org.eclipse.gmt.modisco.omg.kdm.code.CodeItem;
import org.eclipse.gmt.modisco.omg.kdm.code.CodeModel;
import org.eclipse.gmt.modisco.omg.kdm.code.CodeRelationship;
import org.eclipse.gmt.modisco.omg.kdm.code.CommentUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.CompilationUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.CompositeType;
import org.eclipse.gmt.modisco.omg.kdm.code.ComputationalObject;
import org.eclipse.gmt.modisco.omg.kdm.code.ConditionalDirective;
import org.eclipse.gmt.modisco.omg.kdm.code.ControlElement;
import org.eclipse.gmt.modisco.omg.kdm.code.DataElement;
import org.eclipse.gmt.modisco.omg.kdm.code.Datatype;
import org.eclipse.gmt.modisco.omg.kdm.code.DateType;
import org.eclipse.gmt.modisco.omg.kdm.code.DecimalType;
import org.eclipse.gmt.modisco.omg.kdm.code.DefinedType;
import org.eclipse.gmt.modisco.omg.kdm.code.DerivedType;
import org.eclipse.gmt.modisco.omg.kdm.code.EnumeratedType;
import org.eclipse.gmt.modisco.omg.kdm.code.Expands;
import org.eclipse.gmt.modisco.omg.kdm.code.Extends;
import org.eclipse.gmt.modisco.omg.kdm.code.FloatType;
import org.eclipse.gmt.modisco.omg.kdm.code.GeneratedFrom;
import org.eclipse.gmt.modisco.omg.kdm.code.HasType;
import org.eclipse.gmt.modisco.omg.kdm.code.HasValue;
import org.eclipse.gmt.modisco.omg.kdm.code.ImplementationOf;
import org.eclipse.gmt.modisco.omg.kdm.code.Implements;
import org.eclipse.gmt.modisco.omg.kdm.code.Imports;
import org.eclipse.gmt.modisco.omg.kdm.code.IncludeDirective;
import org.eclipse.gmt.modisco.omg.kdm.code.Includes;
import org.eclipse.gmt.modisco.omg.kdm.code.IndexUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.InstanceOf;
import org.eclipse.gmt.modisco.omg.kdm.code.IntegerType;
import org.eclipse.gmt.modisco.omg.kdm.code.InterfaceUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.ItemUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.LanguageUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.MacroDirective;
import org.eclipse.gmt.modisco.omg.kdm.code.MacroUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.MemberUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.MethodUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.Module;
import org.eclipse.gmt.modisco.omg.kdm.code.Namespace;
import org.eclipse.gmt.modisco.omg.kdm.code.OctetType;
import org.eclipse.gmt.modisco.omg.kdm.code.OctetstringType;
import org.eclipse.gmt.modisco.omg.kdm.code.OrdinalType;
import org.eclipse.gmt.modisco.omg.kdm.code.Package;
import org.eclipse.gmt.modisco.omg.kdm.code.ParameterTo;
import org.eclipse.gmt.modisco.omg.kdm.code.ParameterUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.PointerType;
import org.eclipse.gmt.modisco.omg.kdm.code.PreprocessorDirective;
import org.eclipse.gmt.modisco.omg.kdm.code.PrimitiveType;
import org.eclipse.gmt.modisco.omg.kdm.code.RangeType;
import org.eclipse.gmt.modisco.omg.kdm.code.RecordType;
import org.eclipse.gmt.modisco.omg.kdm.code.Redefines;
import org.eclipse.gmt.modisco.omg.kdm.code.ScaledType;
import org.eclipse.gmt.modisco.omg.kdm.code.SequenceType;
import org.eclipse.gmt.modisco.omg.kdm.code.SetType;
import org.eclipse.gmt.modisco.omg.kdm.code.SharedUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.Signature;
import org.eclipse.gmt.modisco.omg.kdm.code.StorableUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.StringType;
import org.eclipse.gmt.modisco.omg.kdm.code.SynonymUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.TemplateParameter;
import org.eclipse.gmt.modisco.omg.kdm.code.TemplateType;
import org.eclipse.gmt.modisco.omg.kdm.code.TemplateUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.TimeType;
import org.eclipse.gmt.modisco.omg.kdm.code.TypeUnit;
import org.eclipse.gmt.modisco.omg.kdm.code.Value;
import org.eclipse.gmt.modisco.omg.kdm.code.ValueElement;
import org.eclipse.gmt.modisco.omg.kdm.code.ValueList;
import org.eclipse.gmt.modisco.omg.kdm.code.VariantTo;
import org.eclipse.gmt.modisco.omg.kdm.code.VisibleIn;
import org.eclipse.gmt.modisco.omg.kdm.code.VoidType;

/**
 * @generated
 */
public class NameProvider extends AbstractNameProvider {
// Start of user code for additional methods and attributes
 	
// End of user code

//	Start of user code name attribute for Value		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getValueName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ValueList		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getValueListName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for SharedUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getSharedUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CallableUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCallableUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for MethodUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getMethodUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for StorableUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getStorableUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ItemUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getItemUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for IndexUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getIndexUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for MemberUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getMemberUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ParameterUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getParameterUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ValueElement		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getValueElementName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for BooleanType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getBooleanTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CharType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCharTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for OrdinalType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getOrdinalTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for DateType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getDateTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for TimeType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getTimeTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for IntegerType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getIntegerTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for DecimalType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getDecimalTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ScaledType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getScaledTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for FloatType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getFloatTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for VoidType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getVoidTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for StringType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getStringTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for BitType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getBitTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for BitstringType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getBitstringTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for OctetType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getOctetTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for OctetstringType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getOctetstringTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ChoiceType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getChoiceTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for RecordType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getRecordTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ArrayType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getArrayTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for PointerType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getPointerTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for RangeType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getRangeTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for BagType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getBagTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for SetType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getSetTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for SequenceType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getSequenceTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for TypeUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getTypeUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for SynonymUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getSynonymUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CompilationUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCompilationUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for LanguageUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getLanguageUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CodeAssembly		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCodeAssemblyName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Package		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getPackageName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ControlElement		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getControlElementName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for DataElement		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getDataElementName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for PrimitiveType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getPrimitiveTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for EnumeratedType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getEnumeratedTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CompositeType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCompositeTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for DerivedType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getDerivedTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Signature		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getSignatureName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for DefinedType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getDefinedTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ClassUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getClassUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for InterfaceUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getInterfaceUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for TemplateUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getTemplateUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for TemplateParameter		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getTemplateParameterName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for TemplateType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getTemplateTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ComputationalObject		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getComputationalObjectName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Datatype		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getDatatypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Module		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getModuleName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for MacroUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getMacroUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for MacroDirective		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getMacroDirectiveName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for IncludeDirective		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getIncludeDirectiveName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ConditionalDirective		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getConditionalDirectiveName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Namespace		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getNamespaceName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CodeElement		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCodeElementName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CodeModel		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCodeModelName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CodeItem		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCodeItemName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for InstanceOf		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getInstanceOfName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ParameterTo		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getParameterToName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Implements		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getImplementsName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for ImplementationOf		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getImplementationOfName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for HasType		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getHasTypeName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for HasValue		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getHasValueName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Extends		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getExtendsName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for PreprocessorDirective		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getPreprocessorDirectiveName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Expands		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getExpandsName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for GeneratedFrom		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getGeneratedFromName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Includes		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getIncludesName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for VariantTo		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getVariantToName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Redefines		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getRedefinesName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for VisibleIn		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getVisibleInName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for Imports		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getImportsName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CodeRelationship		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCodeRelationshipName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for AbstractCodeElement		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getAbstractCodeElementName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for AbstractCodeRelationship		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getAbstractCodeRelationshipName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code
//	Start of user code name attribute for CommentUnit		
	/**
	 * remove this annotation to indicate that code has been changed manually.
	 * @generated
	 */
	private final String getCommentUnitName(EObject eObject) {
		String name = this.getDefaultName(eObject);
		return name;
	}
//	End of user code

	/**
	 * @generated
	 */
	public NameProvider() {
	}

	/**
	 * @return the name that must be displayed for the given {@link EObject}, or <code>null</code>
	 *         to keep the default name (or let another {@link NameProvider} provide the name)
	 * 
	 * @generated
	 */
	public String getName(EObject eObject) {
		String result = this.getDefaultName(eObject);
    	if (eObject instanceof Value) {
      		result = this.getValueName(eObject);
    	} else
    	if (eObject instanceof ValueList) {
      		result = this.getValueListName(eObject);
    	} else
    	if (eObject instanceof SharedUnit) {
      		result = this.getSharedUnitName(eObject);
    	} else
    	if (eObject instanceof CallableUnit) {
      		result = this.getCallableUnitName(eObject);
    	} else
    	if (eObject instanceof MethodUnit) {
      		result = this.getMethodUnitName(eObject);
    	} else
    	if (eObject instanceof StorableUnit) {
      		result = this.getStorableUnitName(eObject);
    	} else
    	if (eObject instanceof ItemUnit) {
      		result = this.getItemUnitName(eObject);
    	} else
    	if (eObject instanceof IndexUnit) {
      		result = this.getIndexUnitName(eObject);
    	} else
    	if (eObject instanceof MemberUnit) {
      		result = this.getMemberUnitName(eObject);
    	} else
    	if (eObject instanceof ParameterUnit) {
      		result = this.getParameterUnitName(eObject);
    	} else
    	if (eObject instanceof ValueElement) {
      		result = this.getValueElementName(eObject);
    	} else
    	if (eObject instanceof BooleanType) {
      		result = this.getBooleanTypeName(eObject);
    	} else
    	if (eObject instanceof CharType) {
      		result = this.getCharTypeName(eObject);
    	} else
    	if (eObject instanceof OrdinalType) {
      		result = this.getOrdinalTypeName(eObject);
    	} else
    	if (eObject instanceof DateType) {
      		result = this.getDateTypeName(eObject);
    	} else
    	if (eObject instanceof TimeType) {
      		result = this.getTimeTypeName(eObject);
    	} else
    	if (eObject instanceof IntegerType) {
      		result = this.getIntegerTypeName(eObject);
    	} else
    	if (eObject instanceof DecimalType) {
      		result = this.getDecimalTypeName(eObject);
    	} else
    	if (eObject instanceof ScaledType) {
      		result = this.getScaledTypeName(eObject);
    	} else
    	if (eObject instanceof FloatType) {
      		result = this.getFloatTypeName(eObject);
    	} else
    	if (eObject instanceof VoidType) {
      		result = this.getVoidTypeName(eObject);
    	} else
    	if (eObject instanceof StringType) {
      		result = this.getStringTypeName(eObject);
    	} else
    	if (eObject instanceof BitType) {
      		result = this.getBitTypeName(eObject);
    	} else
    	if (eObject instanceof BitstringType) {
      		result = this.getBitstringTypeName(eObject);
    	} else
    	if (eObject instanceof OctetType) {
      		result = this.getOctetTypeName(eObject);
    	} else
    	if (eObject instanceof OctetstringType) {
      		result = this.getOctetstringTypeName(eObject);
    	} else
    	if (eObject instanceof ChoiceType) {
      		result = this.getChoiceTypeName(eObject);
    	} else
    	if (eObject instanceof RecordType) {
      		result = this.getRecordTypeName(eObject);
    	} else
    	if (eObject instanceof ArrayType) {
      		result = this.getArrayTypeName(eObject);
    	} else
    	if (eObject instanceof PointerType) {
      		result = this.getPointerTypeName(eObject);
    	} else
    	if (eObject instanceof RangeType) {
      		result = this.getRangeTypeName(eObject);
    	} else
    	if (eObject instanceof BagType) {
      		result = this.getBagTypeName(eObject);
    	} else
    	if (eObject instanceof SetType) {
      		result = this.getSetTypeName(eObject);
    	} else
    	if (eObject instanceof SequenceType) {
      		result = this.getSequenceTypeName(eObject);
    	} else
    	if (eObject instanceof TypeUnit) {
      		result = this.getTypeUnitName(eObject);
    	} else
    	if (eObject instanceof SynonymUnit) {
      		result = this.getSynonymUnitName(eObject);
    	} else
    	if (eObject instanceof CompilationUnit) {
      		result = this.getCompilationUnitName(eObject);
    	} else
    	if (eObject instanceof LanguageUnit) {
      		result = this.getLanguageUnitName(eObject);
    	} else
    	if (eObject instanceof CodeAssembly) {
      		result = this.getCodeAssemblyName(eObject);
    	} else
    	if (eObject instanceof Package) {
      		result = this.getPackageName(eObject);
    	} else
    	if (eObject instanceof ControlElement) {
      		result = this.getControlElementName(eObject);
    	} else
    	if (eObject instanceof DataElement) {
      		result = this.getDataElementName(eObject);
    	} else
    	if (eObject instanceof PrimitiveType) {
      		result = this.getPrimitiveTypeName(eObject);
    	} else
    	if (eObject instanceof EnumeratedType) {
      		result = this.getEnumeratedTypeName(eObject);
    	} else
    	if (eObject instanceof CompositeType) {
      		result = this.getCompositeTypeName(eObject);
    	} else
    	if (eObject instanceof DerivedType) {
      		result = this.getDerivedTypeName(eObject);
    	} else
    	if (eObject instanceof Signature) {
      		result = this.getSignatureName(eObject);
    	} else
    	if (eObject instanceof DefinedType) {
      		result = this.getDefinedTypeName(eObject);
    	} else
    	if (eObject instanceof ClassUnit) {
      		result = this.getClassUnitName(eObject);
    	} else
    	if (eObject instanceof InterfaceUnit) {
      		result = this.getInterfaceUnitName(eObject);
    	} else
    	if (eObject instanceof TemplateUnit) {
      		result = this.getTemplateUnitName(eObject);
    	} else
    	if (eObject instanceof TemplateParameter) {
      		result = this.getTemplateParameterName(eObject);
    	} else
    	if (eObject instanceof TemplateType) {
      		result = this.getTemplateTypeName(eObject);
    	} else
    	if (eObject instanceof ComputationalObject) {
      		result = this.getComputationalObjectName(eObject);
    	} else
    	if (eObject instanceof Datatype) {
      		result = this.getDatatypeName(eObject);
    	} else
    	if (eObject instanceof Module) {
      		result = this.getModuleName(eObject);
    	} else
    	if (eObject instanceof MacroUnit) {
      		result = this.getMacroUnitName(eObject);
    	} else
    	if (eObject instanceof MacroDirective) {
      		result = this.getMacroDirectiveName(eObject);
    	} else
    	if (eObject instanceof IncludeDirective) {
      		result = this.getIncludeDirectiveName(eObject);
    	} else
    	if (eObject instanceof ConditionalDirective) {
      		result = this.getConditionalDirectiveName(eObject);
    	} else
    	if (eObject instanceof Namespace) {
      		result = this.getNamespaceName(eObject);
    	} else
    	if (eObject instanceof CodeElement) {
      		result = this.getCodeElementName(eObject);
    	} else
    	if (eObject instanceof CodeModel) {
      		result = this.getCodeModelName(eObject);
    	} else
    	if (eObject instanceof CodeItem) {
      		result = this.getCodeItemName(eObject);
    	} else
    	if (eObject instanceof InstanceOf) {
      		result = this.getInstanceOfName(eObject);
    	} else
    	if (eObject instanceof ParameterTo) {
      		result = this.getParameterToName(eObject);
    	} else
    	if (eObject instanceof Implements) {
      		result = this.getImplementsName(eObject);
    	} else
    	if (eObject instanceof ImplementationOf) {
      		result = this.getImplementationOfName(eObject);
    	} else
    	if (eObject instanceof HasType) {
      		result = this.getHasTypeName(eObject);
    	} else
    	if (eObject instanceof HasValue) {
      		result = this.getHasValueName(eObject);
    	} else
    	if (eObject instanceof Extends) {
      		result = this.getExtendsName(eObject);
    	} else
    	if (eObject instanceof PreprocessorDirective) {
      		result = this.getPreprocessorDirectiveName(eObject);
    	} else
    	if (eObject instanceof Expands) {
      		result = this.getExpandsName(eObject);
    	} else
    	if (eObject instanceof GeneratedFrom) {
      		result = this.getGeneratedFromName(eObject);
    	} else
    	if (eObject instanceof Includes) {
      		result = this.getIncludesName(eObject);
    	} else
    	if (eObject instanceof VariantTo) {
      		result = this.getVariantToName(eObject);
    	} else
    	if (eObject instanceof Redefines) {
      		result = this.getRedefinesName(eObject);
    	} else
    	if (eObject instanceof VisibleIn) {
      		result = this.getVisibleInName(eObject);
    	} else
    	if (eObject instanceof Imports) {
      		result = this.getImportsName(eObject);
    	} else
    	if (eObject instanceof CodeRelationship) {
      		result = this.getCodeRelationshipName(eObject);
    	} else
    	if (eObject instanceof AbstractCodeElement) {
      		result = this.getAbstractCodeElementName(eObject);
    	} else
    	if (eObject instanceof AbstractCodeRelationship) {
      		result = this.getAbstractCodeRelationshipName(eObject);
    	} else
    	if (eObject instanceof CommentUnit) {
      		result = this.getCommentUnitName(eObject);
    	} 
		return result;
	}

}

